@@ -17,7 +17,6 @@
 
 import hashlib
 import requests
-from requests import RequestException
 
 
 class Pwned:
@@ -147,7 +146,7 @@ class Pwned:
     400    Bad request — the account does not comply with an acceptable
            format (i.e. it's an empty string).
 
-    401    Unauthorised — the API key provided was not valid
+    401    Unauthorized — the API key provided was not valid
 
     403    Forbidden — no user agent has been specified in the request.
 
@@ -230,7 +229,7 @@ class Pwned:
             truncate = ''
         else:
             truncate = '?truncateResponse=false'
-        if domain == None:
+        if domain is None:
             domain = ''
         else:
             domain = '?domain=' + domain
@@ -266,7 +265,7 @@ class Pwned:
         """
 
         url = 'https://haveibeenpwned.com/api/v3/breaches'
-        if domain == None:
+        if domain is None:
             domain = ''
         else:
             domain = '?domain=' + domain
@@ -477,7 +476,7 @@ class Pwned:
                 print("Bad request: The account does not comply with an" +
                       " acceptable format (i.e. it's an empty string)")
             elif resp.status_code == 401:
-                print("Unauthorised — the API key provided was not valid")
+                print("Unauthorized — the API key provided was not valid")
             elif resp.status_code == 403:
                 print("Forbidden: No user agent has" +
                       " been specified in the request")
@@ -487,6 +486,6 @@ class Pwned:
             elif resp.status_code == 429:
                 print("Too many requests: The rate limit has been exceeded\n")
                 print(resp.text)
-        except RequestException:
+        except requests.RequestException:
             print("ERROR: Could not connect to server")
 
